@@ -13,9 +13,10 @@ pub fn message(options: &Options) -> String {
 
 {field_getters}
 
-void {ns}__diagnostic_message__drop({diagnostic_message_blob} *self_blob);
+void {fn_attributes} {ns}__diagnostic_message__drop({diagnostic_message_blob} *self_blob);
 ",
         ns = GLOBAL_NS,
+        fn_attributes = options.fn_attributes,
         constructors = constructors(options),
         variant_getters = variant_getters(options),
         variant_predicates = variant_predicates(options),
