@@ -40,8 +40,10 @@ extern \"C\" {{
 // variant drop fns
 {variant_drop_fns}
 
-void {ns}__node__drop({node_blob}* self_blob);
+void {fn_attributes} {ns}__node__drop({node_blob}* self_blob);
 ",
+        ns = GLOBAL_NS,
+        fn_attributes = options.fn_attributes,
         constructors = constructors(&options),
         variant_predicates = variant_predicates(&options),
         variant_getters = variant_getters(&options),
@@ -51,7 +53,6 @@ void {ns}__node__drop({node_blob}* self_blob);
         into_variant_fns = into_variant_fns(&options),
         into_internal_fns = into_internal_fns(&options),
         variant_drop_fns = variant_drop_fns(&options),
-        ns = GLOBAL_NS,
         node_blob = options.node_blob_name
     )
 }
