@@ -27,8 +27,9 @@ fn arglist(message: &Message, options: &Options) -> String {
 /// Returns C signature of the message constructor for the given `message`
 pub fn sig(message: &Message, options: &Options) -> String {
     format!(
-        "{diagnostic_message_blob} {constructor_name}({arglist})",
+        "{diagnostic_message_blob} {fn_attributes} {constructor_name}({arglist})",
         diagnostic_message_blob = options.diagnostic_message_blob_name,
+        fn_attributes = options.fn_attributes,
         constructor_name = name(message),
         arglist = arglist(message, options)
     )
