@@ -22,9 +22,10 @@ fn arglist(node: &Node, options: &Options) -> String {
 /// Returns C signature of the constructor for the given `node`
 pub fn sig(node: &Node, options: &Options) -> String {
     format!(
-        "{node_blob} {constructor_name}({arglist})",
-        constructor_name = name(node),
+        "{node_blob} {fn_attributes} {constructor_name}({arglist})",
         node_blob = options.node_blob_name,
+        fn_attributes = options.fn_attributes,
+        constructor_name = name(node),
         arglist = arglist(node, options)
     )
 }
