@@ -10,8 +10,9 @@ pub fn name(node: &Node) -> String {
 /// Returns name of the cast-to-variant function for the given `node`
 pub fn sig(node: &Node, options: &Options) -> String {
     format!(
-        "{node_variant_blob} *{variant_getter_name}(Node_BLOB *self_blob)",
+        "{node_variant_blob} *{fn_attributes} {variant_getter_name}(Node_BLOB *self_blob)",
         node_variant_blob = options.node_variant_blob_name(node),
+        fn_attributes = options.fn_attributes,
         variant_getter_name = name(node)
     )
 }
