@@ -22,6 +22,11 @@ pub struct Options {
     /// Default: `"// post-code"`
     pub post_code: String,
 
+    /// Attributes that are attached to every generated function
+    ///
+    /// can be `__attribute__((always_inline))` if you want to perform inlining
+    pub fn_attributes: String,
+
     /// Name of what you want to be used
     /// **as a blob** of the `Ptr<T>` struct in `lib-ruby-parser`
     pub ptr_blob_name: String,
@@ -206,6 +211,7 @@ impl Default for Options {
             ifndef_name: String::from("LIB_RUBY_PARSER_BINDINGS_H"),
             pre_code: String::from("// pre-code"),
             post_code: String::from("// post-code"),
+            fn_attributes: String::from(""),
 
             // blob names
             ptr_blob_name: String::from("Ptr_BLOB"),
